@@ -6,7 +6,7 @@
   if (substr(jv, 1L, 2L) == "1.") {
 	  jvn = as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
 	  if (jvn < 1.7){
-		  warning("Java 7 (at minimum) is needed for this package but is does not seem to be available. This message may be in error; apologies if it is.")
+		  warning(paste("Java v", jvn, "detected. Java 7 (at minimum) is needed for this package but is does not seem to be available. This message may be in error; apologies if it is."))
 	  }		
   }
 }
